import inquirer from 'inquirer';
import getSolveData from '../utils/getSolveData.js';
import printTable from '../utils/printTable.js';
import handlePagination from '../utils/handlePagination.js';
import { statuses } from '../lib/routes.js';
import { nextPageOption, previousPageOption } from '../lib/options.js';
const showStatus = async (SessionId, query = '', page = 1, myOnly) => {
    const { records, total_pages } = await getSolveData(SessionId, statuses, '', { page, query, param: myOnly ? true : false });
    const title = query.length ? `🔍 Search: ${query}` : 'Recent submissions';
    const descriptionColumns = ['ID', 'Author', 'Test', 'Task', 'Status', 'Time', 'Memory', 'Result', 'Date'];
    const dataTemplate = ['id', 'author', 'test', 'task', 'status', 'time_used', 'mem_used', 'result', 'time'];
    printTable(title, descriptionColumns, records, dataTemplate, `Page: ${page}/${total_pages}`);
    selectPage(SessionId, query, page, total_pages, myOnly);
};
const selectPage = (SessionId, query = '', page, totalPages, myOnly = false) => {
    const choices = [...handlePagination(page, totalPages)];
    inquirer
        .prompt([
        {
            type: 'list',
            message: `Select option`,
            name: 'option',
            choices: choices,
            loop: true,
        },
    ])
        .then(({ option }) => {
        switch (option) {
            case nextPageOption:
                showStatus(SessionId, query, page + 1, myOnly);
                break;
            case previousPageOption:
                showStatus(SessionId, query, page - 1, myOnly);
                break;
        }
    });
};
export default showStatus;
//# sourceMappingURL=status.js.map